{% extends "base.jinja" %}


{% block sidebar %}
{% endblock %}

{% block main %}
    <style>
        .big_option {
            display: inline-block;
            width: 12em;
            padding: 1em;
            vertical-align: middle;
            height: 3.5em;
            border: 4px solid var(--cmap-border);
            border-radius: 0.5em;
            background-color: var(--cmap-bg-lighter);
            font-size: 1.5em;
            margin: 1em;
            position: relative;
        }
        .big_option:hover {
            background-color: var(--cmap-bg-lightest);
            border: 4px solid var(--main-color);
            cursor: pointer;
        }

        .big_option_text {
            margin: 0;
            position: absolute;
            top: 50%;
            left: 50%;
            -ms-transform: translate(-50%, -50%);
            transform: translate(-50%, -50%);
        }

        .instructions {
            color: #999;
            font-style: italic;
        }
    </style>
    <img src="{{ url_for(service.id +'_endpoint' + '.static', filename=service.logo) }}" width="300"/>
    <div class="card center" style="width: auto; min-width: 90%; margin: 40px;">
        <h1>{{ _("Swan Integration Success!") }}</h1>
        <br/>
        <h2>{{ _("You can close this browser tab now.") }}</h2>
    </div>
{% endblock %}



{% block scripts %}
    <script>
    </script>
{% endblock %}